---
name: Feature Request
about: Use this to suggest new feature/enhancements
title: "[scope] summary of your request"
labels: state/awaiting-triage, type/feat
assignees: ''

---

# Feature Request
<!--
  Explain your request in great detail (required).

  Things to consider:
   - Why should we add this feature/enhancement
   - What problem(s) does it solve
   - Complexity
   - How we should implement it
-->

## Example (if possible)
<!--
  If possible demonstrate your request via a JSFiddle.

  How to create an example:
   1. Open the following JSFiddle - https://jsfiddle.net/31d6y7mn
   2. Click "Fork" at the top
   3. Add the HTML, CSS and JavaScript which shows your request 
   4. Click "Save" at the top
   5. Copy the URL of your fiddle and link it here
-->

## Screenshot (if possible)
<!--
  If possible include images or gifs of your request.

  E.g. new component request should include images of the component
  in other frameworks and on websites.
  
  If your looking for a tool we recommend ShareX - https://github.com/ShareX/ShareX
-->
